@@ -60,6 +60,11 @@ class Gcompris_algorithm:
     self.distance = 80
     self.leftx = 90
 
+    # These are used to let us restart only after the bonus is displayed.
+    # When the bonus is displayed, it call us first with pause(1) and then with pause(0)
+    self.board_paused  = 0;
+    self.gamewon       = 0;
+
   def start(self): 
     gcompris.bar_set (0) 
     gcompris.set_background(self.gcomprisBoard.canvas.root(),
@@ -88,6 +93,24 @@ class Gcompris_algorithm:
   def ok(self):
     print("Gcompris_algorithm ok.")
 
+  # Called by gcompris core 
+  def pause(self, pause):
+    
+    self.board_paused = pause
+    
+    # When the bonus is displayed, it call us first with pause(1) and then with pause(0)
+    # the game is won
+    if(pause == 0):
+      self.increment_level()
+      self.gamewon = 0
+
+    return
+  
+  # ----------------------------------------------------------------------
+  # ----------------------------------------------------------------------
+  # ----------------------------------------------------------------------
+
+
   def cleanup(self):
     
     # Remove the root item removes all the others inside it
@@ -146,7 +169,7 @@ class Gcompris_algorithm:
   def paint_qm (self):
     self.qm = self.rootitem.add(gnome.canvas.CanvasText, text = "?", 
      x = self.place*self.distance+30+self.leftx, 
-     y = 185, fill_color_rgba = 0xff0000ffL, 
+     y = 185, fill_color_rgba = 0x000000ffL, 
      font = gcompris.skin.get_font("gcompris/board/huge bold"))
     
   def key_press(self, keyval):
@@ -184,8 +207,8 @@ class Gcompris_algorithm:
       self.paint_image(index, self.place, 147)
       self.place +=1
       if self.place == self.anzahl:
-       self.increment_level()
-       return
+        gcompris.bonus.display(gcompris.bonus.WIN, gcompris.bonus.TUX)
+        return
       self.paint_qm ()
 
   def increment_level(self):
