@@ -1,6 +1,6 @@
 /* gcompris - gameutil.c
  *
- * Time-stamp: <2005/02/16 22:11:28 bruno>
+ * Time-stamp: <2005/04/10 23:50:40 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -116,18 +116,15 @@ GdkPixbuf *gcompris_load_pixmap_asset(gchar *dataset, gchar* categories,
 GdkPixbuf *gcompris_load_pixmap(char *pixmapfile)
 {
   gchar *filename;
-  GdkPixbuf *pixmap;
+  GdkPixbuf *pixmap=NULL;
 
+  /* Search */
 
-  /* Search it on the file system */
-  if (!g_path_is_absolute (pixmapfile))
-    filename = g_strdup_printf("%s/%s", PACKAGE_DATA_DIR, pixmapfile);
-  else 
-    filename = pixmapfile;
+  filename = gcompris_find_absolute_filename(pixmapfile);
 
-  if (!g_file_test ((filename), G_FILE_TEST_EXISTS)) {
+  if (!filename) {
     char *str;
-    g_warning (_("Couldn't find file %s !"), filename);
+    g_warning (_("Couldn't find file %s !"), pixmapfile);
 
     str = g_strdup_printf("%s\n%s\n%s\n%s", 
 			  _("Couldn't find file"), 
@@ -136,10 +133,13 @@ GdkPixbuf *gcompris_load_pixmap(char *pixmapfile)
 			  _("Exit it and report\nthe problem to the authors."));
     gcompris_dialog (str, NULL);
     g_free(str);
+    return NULL;
   }
 
   pixmap = gdk_pixbuf_new_from_file (filename, NULL);
 
+  g_free(filename);
+
   if(!pixmap)
     g_warning("Loading image returned a null pointer");
 
@@ -575,11 +575,37 @@ GcomprisBoard *gcompris_get_board_from_section(gchar *section)
   for(list = boards_list; list != NULL; list = list->next) {
     GcomprisBoard *board = list->data;
 
-    if( board->section && (strcmp (board->section, section) == 0))
-      {
+    if (strcmp (board->type,"menu") == 0){
+
+    g_warning("gcompris_get_board_from_section searching '%s' in menu board %s", section, board->section);
+
+      if( board->section && (strcmp (board->section, section) == 0))
+	{
+	  g_warning("gcompris_get_board_from_section found '%s' in board '%s'\n", section, board->section);
+	  return board;
+	}
+    }
+    else {
+      gchar *fullname = NULL;
+      gchar *path = NULL;
+
+      path = g_strndup (board->section,strlen(board->section)-2);
+
+      fullname = g_strdup_printf("%s/%s",
+				 path, board->name);
+
+      g_free(path);
+
+      g_warning("gcompris_get_board_from_section searching '%s' in menu board %s", section, fullname);
+
+      if (strcmp (fullname, section) == 0){
+	g_free(fullname);
 	return board;
       }
+      g_free(fullname);
+    }
   }
+  g_warning("gcompris_get_board_from_section searching '%s' but NOT FOUND\n", section);
   return NULL;
 }
 
@@ -643,25 +669,21 @@ void cleanup_menus() {
   }
 }
 
-/* load all the menus xml files in the gcompris path
- * into our memory structures.
+/*
+ * gcompris_load_menus
+ *
+ * Load all the menu it can from the given dirname
+ *
  */
-void gcompris_load_menus()
-{
+void gcompris_load_menus_dir(char *dirname){
   struct dirent *one_dirent;
   DIR *dir;
   int n;
 
-  if(boards_list) {
-    cleanup_menus();
-    return;
-  }
-
-  /* Load the Pixpmaps directory file names */
-  dir = opendir(PACKAGE_DATA_DIR);
+  dir = opendir(dirname);
 
   if (!dir) {
-    g_warning("gcompris_load_menus : no menu found in %s", PACKAGE_DATA_DIR);
+    g_warning("gcompris_load_menus : no menu found in %s", dirname);
   } else {
 
     while((one_dirent = readdir(dir)) != NULL) {
@@ -670,7 +692,7 @@ void gcompris_load_menus()
       gchar *filename;
       
       filename = g_strdup_printf("%s/%s",
-				 PACKAGE_DATA_DIR, one_dirent->d_name);
+				 dirname, one_dirent->d_name);
 
       if(!g_file_test(filename, G_FILE_TEST_IS_REGULAR)) {
 	g_free(filename);
@@ -679,6 +701,7 @@ void gcompris_load_menus()
 
       if(selectMenuXML(one_dirent->d_name)) {
 	gcomprisBoard = g_malloc0 (sizeof (GcomprisBoard));
+	gcomprisBoard->board_dir = dirname;
 
 	/* Need to be initialized here because gcompris_read_xml_file is used also to reread 	*/
 	/* the locale data									*/
@@ -694,8 +717,26 @@ void gcompris_load_menus()
     }
   }
   closedir(dir);
+}
 
-  gcompris_get_menulist("/");
+/* load all the menus xml files in the gcompris path
+ * into our memory structures.
+ */
+void gcompris_load_menus()
+{
+  GcomprisProperties	*properties = gcompris_get_properties();
+
+  if(boards_list) {
+    cleanup_menus();
+    return;
+  }
+
+  gcompris_load_menus_dir(properties->package_data_dir);
+
+  if (properties->local_directory)
+    gcompris_load_menus_dir(properties->local_directory);
+
+  gcompris_get_menulist(properties->root_menu);
 }
 
 /* ======================================= */
@@ -1048,6 +1089,32 @@ gchar *g_utf8_strndup(gchar* utf8text, gint n)
  return result;
 } 
 
+gchar *gcompris_find_absolute_filename(gchar *filename)
+{
+  gchar *absolute_filename;
+  GcomprisProperties	*properties = gcompris_get_properties();
+
+  /* Search it on the file system */
+
+  if (!g_path_is_absolute (filename)) {
+    absolute_filename = g_strdup_printf("%s/%s", properties->package_data_dir, filename);
+    if (!g_file_test (absolute_filename, G_FILE_TEST_EXISTS)) {
+      GcomprisBoard   *gcomprisBoard = get_current_gcompris_board();
+      g_free(absolute_filename);
+      absolute_filename = g_strdup_printf("%s/%s", gcomprisBoard->board_dir, filename);
+    }
+  } else {
+    absolute_filename = strdup(filename);
+  }
+
+  if (!g_file_test (absolute_filename, G_FILE_TEST_EXISTS)){
+    g_free(absolute_filename);
+    return NULL;
+  }
+
+  return absolute_filename;
+}
+
 
 /* Local Variables: */
 /* mode:c */
