@@ -1,6 +1,6 @@
 /* gcompris - properties.c
  *
- * Time-stamp: <2005/03/29 00:58:14 bruno>
+ * Time-stamp: <2005/04/17 16:50:21 bruno>
  *
  * Copyright (C) 2000,2003 Bruno Coudoin
  *
@@ -92,7 +92,11 @@ create_rootdir (gchar *rootdir)
     return 0;
   }
 
+#if defined WIN32
+  return(mkdir(rootdir));
+#else
   return(mkdir(rootdir, 0755));
+#endif
 }
 
 GcomprisProperties *gcompris_properties_new ()
@@ -120,7 +124,9 @@ GcomprisProperties *gcompris_properties_new ()
   tmp->difficulty_max    = 0;
   tmp->filter_style      = GCOMPRIS_FILTER_NONE;	/* No difficulty filter by default */
   tmp->difficulty_filter = 1;				/* No difficulty filter by default */
-
+  tmp->root_menu         = "/";
+  tmp->local_directory   = NULL;
+  tmp->package_data_dir  = PACKAGE_DATA_DIR;
 
   home_dir = g_get_home_dir();
 
